Puput
=====

.. image:: https://readthedocs.org/projects/puput/badge/?version=latest
    :target: https://readthedocs.org/projects/puput/?badge=latest
    
.. image:: https://api.codacy.com/project/badge/grade/f96e31ee1b8c4aa2b1402f12308afe96    
   :target: https://www.codacy.com/app/marctc/puput
   
Puput is a powerful and simple Django app to manage a blog. It uses the awesome `Wagtail CMS <https://github.com/torchbox/wagtail>`_ as content management system.

Puput is the catalan name for `Hoopoe <https://en.wikipedia.org/wiki/Hoopoe>`_ which is indeed a beautiful bird.

.. image:: http://i.imgur.com/3ByGQb6.png

`Try Puput demo site! <http://puput.apsl.net/>`_

Features
~~~~~~~~

* Built with Wagtail CMS and Django
* Inspired in Wordpress and Zinnia
* Simple & responsive HTML template by default
* SEO friendly urls
* Support for Disqus comments
* Entries by author, tags, categories, archives and search term
* Last & popular entries
* Configurable sidebar widgets
* RSS feeds
* Related entries
* Extensible entry model

.. image:: http://i.imgur.com/ndZLeWb.png

Setup
~~~~~

The setup process is explained `here <docs/setup.rst>`_.

Documentation
~~~~~~~~~~~~~
Visit the `documentation <http://puput.readthedocs.org>`_ for an in-depth look at Puput.
